@@ -1,7 +1,8 @@
 package constant::Atom::Strict;
 
-use strict; use warnings;
-our $VERSION = '0.011';
+use strict;
+use warnings;
+our $VERSION = '0.06';
 
 use Carp;
 
@@ -13,4 +14,4 @@ sub tostring {
 	croak "Can't cast $class object '".$$self."' into a string.  Use the 'fullname' method for a string representation of this object";	
 }
 
-1;
\ No newline at end of file
+1;
